from random import choice

DESKTOP_AGENTS = ['Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/54.0.2840.99 Safari/537.36',
                 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/54.0.2840.99 Safari/537.36',
                 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/54.0.2840.99 Safari/537.36',
                 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_1) AppleWebKit/602.2.14 (KHTML, like Gecko) Version/10.0.1 Safari/602.2.14',
                 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/54.0.2840.71 Safari/537.36',
                 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/54.0.2840.98 Safari/537.36',
                 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/54.0.2840.98 Safari/537.36',
                 'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/54.0.2840.71 Safari/537.36',
                 'Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/54.0.2840.99 Safari/537.36',
                 'Mozilla/5.0 (Windows NT 10.0; WOW64; rv:50.0) Gecko/20100101 Firefox/50.0']


def random_desktop_headers():
    return {'User-Agent': choice(DESKTOP_AGENTS),
            'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8'}



google_geos = {
    'com': 'https://www.google.com/search?q={}&num={}&hl=en',
    'ac': 'https://www.google.ac/search?q={}&num={}&hl=en',
    'ad': 'https://www.google.ad/search?q={}&num={}&hl=es',
    'ae': 'https://www.google.ae/search?q={}&num={}&hl=ar',
    'af': 'https://www.google.com.af/search?q={}&num={}&hl=ps',
    'ag': 'https://www.google.com.ag/search?q={}&num={}&hl=en',
    'ai': 'https://www.google.com.ai/search?q={}&num={}&hl=en',
    'al': 'https://www.google.al/search?q={}&num={}&hl=sq',
    'am': 'https://www.google.am/search?q={}&num={}&hl=hy',
    'ao': 'https://www.google.co.ao/search?q={}&num={}&hl=pt-PT',
    'ar': 'https://www.google.com.ar/search?q={}&num={}&hl=es-419',
    'as': 'https://www.google.as/search?q={}&num={}&hl=en',
    'at': 'https://www.google.at/search?q={}&num={}&hl=de',
    'au': 'https://www.google.com.au/search?q={}&num={}&hl=en',
    'az': 'https://www.google.az/search?q={}&num={}&hl=az',
    'ba': 'https://www.google.ba/search?q={}&num={}&hl=bs',
    'bd': 'https://www.google.com.bd/search?q={}&num={}&hl=bn',
    'be': 'https://www.google.be/search?q={}&num={}',
    'bf': 'https://www.google.bf/search?q={}&num={}&hl=fr',
    'bg': 'https://www.google.bg/search?q={}&num={}&hl=bg',
    'bh': 'https://www.google.com.bh/search?q={}&num={}&hl=ar',
    'bi': 'https://www.google.bi/search?q={}&num={}&hl=fr',
    'bj': 'https://www.google.bj/search?q={}&num={}&hl=fr',
    'bn': 'https://www.google.com.bn/search?q={}&num={}&hl=fr',
    'bo': 'https://www.google.com.bo/search?q={}&num={}&hl=es-419',
    'br': 'https://www.google.com.br/search?q={}&num={}&hl=pt-BR',
    'bs': 'https://www.google.bs/search?q={}&num={}&hl=en',
    'bt': 'https://www.google.bt/search?q={}&num={}',
    'bw': 'https://www.google.co.bw/search?q={}&num={}&hl=en',
    'by': 'https://www.google.by/search?q={}&num={}&hl=be',
    'bz': 'https://www.google.com.bz/search?q={}&num={}&hl=en',
    'ca': 'https://www.google.ca/search?q={}&num={}',
    'kh': 'https://www.google.com.kh/search?q={}&num={}',
    'cc': 'https://www.google.cc/search?q={}&num={}&hl=en',
    'cd': 'https://www.google.cd/search?q={}&num={}&hl=fr',
    'cf': 'https://www.google.cf/search?q={}&num={}&hl=fr',
    'cat': 'https://www.google.cat/search?q={}&num={}&hl=ca',
    'cg': 'https://www.google.cg/search?q={}&num={}&hl=fr',
    'ch': 'https://www.google.ch/search?q={}&num={}',
    'ci': 'https://www.google.ci/search?q={}&num={}&hl=en',
    'ck': 'https://www.google.co.ck/search?q={}&num={}&hl=en',
    'cl': 'https://www.google.cl/search?q={}&num={}&hl={}',
    'cm': 'https://www.google.cm/search?q={}&num={}',
    'co': 'https://www.google.com.co/search?q={}&num={}&hl=es-419',
    'cr': 'https://www.google.co.cr/search?q={}&num={}&hl=es',
    'cu': 'https://www.google.com.cu/search?q={}&num={}&hl=es',
    'cv': 'https://www.google.cv/search?q={}&num={}&hl=pt',
    'cy': 'https://www.google.com.cy/search?q={}&num={}&hl=el',
    'cz': 'https://www.google.cz/search?q={}&num={}&hl=cz',
    'de': 'https://www.google.de/search?q={}&num={}&hl=de',
    'dj': 'https://www.google.dj/search?q={}&num={}',
    'dk': 'https://www.google.dk/search?q={}&num={}&hl=da',
    'dm': 'https://www.google.dm/search?q={}&num={}&hl=en',
    'do': 'https://www.google.com.do/search?q={}&num={}&hl=es',
    'dz': 'https://www.google.dz/search?q={}&num={}',
    'ec': 'https://www.google.com.ec/search?q={}&num={}&hl=es-419',
    'ee': 'https://www.google.ee/search?q={}&num={}&hl=et',
    'eg': 'https://www.google.com.eg/search?q={}&num={}&hl=ar',
    'es': 'https://www.google.es/search?q={}&num={}&hl=es',
    'et': 'https://www.google.com.et/search?q={}&num={}&hl=am',
    'fi': 'https://www.google.fi/search?q={}&num={}&hl=fi',
    'fj': 'https://www.google.com.fj/search?q={}&num={}&hl=en',
    'fm': 'https://www.google.fm/search?q={}&num={}',
    'fr': 'https://www.google.fr/search?q={}&num={}&hl=fr',
    'ga': 'https://www.google.ga/search?q={}&num={}&hl=fr',
    'ge': 'https://www.google.ge/search?q={}&num={}&hl=ka',
    'gf': 'https://www.google.gf/search?q={}&num={}&hl=fr',
    'gg': 'https://www.google.gg/search?q={}&num={}&hl=en',
    'gh': 'https://www.google.com.gh/search?q={}&num={}&hl=en',
    'gi': 'https://www.google.com.gi/search?q={}&num={}&hl=en',
    'gl': 'https://www.google.gl/search?q={}&num={}',
    'gm': 'https://www.google.gm/search?q={}&num={}&hl=en',
    'gp': 'https://www.google.gp/search?q={}&num={}&hl=fr',
    'gr': 'https://www.google.gr/search?q={}&num={}&hl=el',
    'gt': 'https://www.google.com.gt/search?q={}&num={}&hl=es-419',
    'gy': 'https://www.google.gy/search?q={}&num={}&hl=en',
    'hk': 'https://www.google.com.hk/search?q={}&num={}&hl=zh-CN',
    'hn': 'https://www.google.hn/search?q={}&num={}&hl=es-419',
    'hr': 'https://www.google.hr/search?q={}&num={}&hl=hr',
    'ht': 'https://www.google.ht/search?q={}&num={}&hl=fr',
    'hu': 'https://www.google.hu/search?q={}&num={}&hl=hu',
    'id': 'https://www.google.co.id/search?q={}&num={}&hl=id',
    'iq': 'https://www.google.iq/search?q={}&num={}',
    'ie': 'https://www.google.ie/search?q={}&num={}',
    'il': 'https://www.google.co.il/search?q={}&num={}&hl=iw',
    'im': 'https://www.google.im/search?q={}&num={}',
    'in': 'https://www.google.co.in/search?q={}&num={}',
    'io': 'https://www.google.io/search?q={}&num={}',
    'is': 'https://www.google.is/search?q={}&num={}&hl=is',
    'it': 'https://www.google.it/search?q={}&num={}&hl=it',
    'je': 'https://www.google.je/search?q={}&num={}&hl=en',
    'jm': 'https://www.google.com.jm/search?q={}&num={}&hl=en',
    'jo': 'https://www.google.jo/search?q={}&num={}&hl=ar',
    'jp': 'https://www.google.co.jp/search?q={}&num={}&hl=ja',
    'ke': 'https://www.google.co.ke/search?q={}&num={}',
    'ki': 'https://www.google.ki/search?q={}&num={}',
    'kg': 'https://www.google.kg/search?q={}&num={}&hl=ky',
    'kr': 'https://www.google.co.kr/search?q={}&num={}&hl=ko',
    'kw': 'https://www.google.com.kw/search?q={}&num={}&hl=ar',
    'kz': 'https://www.google.kz/search?q={}&num={}',
    'la': 'https://www.google.la/search?q={}&num={}',
    'lb': 'https://www.google.com.lb/search?q={}&num={}&hl=ar',
    'lc': 'https://www.google.com.lc/search?q={}&num={}',
    'li': 'https://www.google.li/search?q={}&num={}',
    'lk': 'https://www.google.lk/search?q={}&num={}',
    'ls': 'https://www.google.co.ls/search?q={}&num={}',
    'lt': 'https://www.google.lt/search?q={}&num={}&hl=lt',
    'lu': 'https://www.google.lu/search?q={}&num={}',
    'lv': 'https://www.google.lv/search?q={}&num={}&hl=lv',
    'ly': 'https://www.google.com.ly/search?q={}&num={}',
    'ma': 'https://www.google.co.ma/search?q={}&num={}',
    'md': 'https://www.google.md/search?q={}&num={}',
    'me': 'https://www.google.me/search?q={}&num={}&hl=sr-ME',
    'mg': 'https://www.google.mg/search?q={}&num={}',
    'mk': 'https://www.google.mk/search?q={}&num={}&hl=mk',
    'ml': 'https://www.google.ml/search?q={}&num={}',
    'mm': 'https://www.google.com.mm/search?q={}&num={}',
    'mn': 'https://www.google.mn/search?q={}&num={}&hl=mn',
    'ms': 'https://www.google.ms/search?q={}&num={}',
    'mt': 'https://www.google.com.mt/search?q={}&num={}',
    'mu': 'https://www.google.mu/search?q={}&num={}',
    'mv': 'https://www.google.mv/search?q={}&num={}',
    'mw': 'https://www.google.mw/search?q={}&num={}',
    'mx': 'https://www.google.com.mx/search?q={}&num={}&hl=es',
    'my': 'https://www.google.com.my/search?q={}&num={}&hl={}',
    'mz': 'https://www.google.co.mz/search?q={}&num={}',
    'na': 'https://www.google.com.na/search?q={}&num={}',
    'ne': 'https://www.google.ne/search?q={}&num={}',
    'nf': 'https://www.google.com.nf/search?q={}&num={}',
    'ng': 'https://www.google.com.ng/search?q={}&num={}',
    'ni': 'https://www.google.com.ni/search?q={}&num={}&hl=es-419',
    'nl': 'https://www.google.nl/search?q={}&num={}&hl=nl',
    'no': 'https://www.google.no/search?q={}&num={}&hl=no',
    'np': 'https://www.google.com.np/search?q={}&num={}&hl=ne',
    'nr': 'https://www.google.nr/search?q={}&num={}',
    'nu': 'https://www.google.nu/search?q={}&num={}',
    'nz': 'https://www.google.co.nz/search?q={}&num={}&hl=en',
    'om': 'https://www.google.com.om/search?q={}&num={}',
    'pk': 'https://www.google.com.pk/search?q={}&num={}',
    'pa': 'https://www.google.com.pa/search?q={}&num={}',
    'pe': 'https://www.google.com.pe/search?q={}&num={}&hl=es-419',
    'ph': 'https://www.google.com.ph/search?q={}&num={}',
    'pl': 'https://www.google.pl/search?q={}&num={}&hl=pl',
    'pg': 'https://www.google.com.pg/search?q={}&num={}',
    'pn': 'https://www.google.pn/search?q={}&num={}',
    'pr': 'https://www.google.com.pr/search?q={}&num={}',
    'ps': 'https://www.google.ps/search?q={}&num={}',
    'pt': 'https://www.google.pt/search?q={}&num={}&hl=pt-PT',
    'py': 'https://www.google.com.py/search?q={}&num={}&hl=es-419',
    'qa': 'https://www.google.com.qa/search?q={}&num={}',
    'ro': 'https://www.google.ro/search?q={}&num={}&hl=ro',
    'rs': 'https://www.google.rs/search?q={}&num={}&hl=sr',
    'ru': 'https://www.google.ru/search?q={}&num={}&hl=ru',
    'rw': 'https://www.google.rw/search?q={}&num={}',
    'sa': 'https://www.google.com.sa/search?q={}&num={}&hl=ar',
    'sb': 'https://www.google.com.sb/search?q={}&num={}',
    'sc': 'https://www.google.sc/search?q={}&num={}',
    'se': 'https://www.google.se/search?q={}&num={}&hl=sv',
    'sg': 'https://www.google.com.sg/search?q={}&num={}',
    'sh': 'https://www.google.sh/search?q={}&num={}',
    'si': 'https://www.google.si/search?q={}&num={}&hl=sl',
    'sk': 'https://www.google.sk/search?q={}&num={}&hl=sk',
    'sl': 'https://www.google.com.sl/search?q={}&num={}',
    'sn': 'https://www.google.sn/search?q={}&num={}',
    'sm': 'https://www.google.sm/search?q={}&num={}',
    'so': 'https://www.google.so/search?q={}&num={}&hl=so',
    'st': 'https://www.google.st/search?q={}&num={}',
    'sr': 'https://www.google.sr/search?q={}&num={}',
    'sv': 'https://www.google.com.sv/search?q={}&num={}&hl=es-419',
    'td': 'https://www.google.td/search?q={}&num={}',
    'tg': 'https://www.google.tg/search?q={}&num={}',
    'th': 'https://www.google.co.th/search?q={}&num={}&hl=th',
    'tj': 'https://www.google.com.tj/search?q={}&num={}&hl=tg',
    'tk': 'https://www.google.tk/search?q={}&num={}',
    'tl': 'https://www.google.tl/search?q={}&num={}',
    'tm': 'https://www.google.tm/search?q={}&num={}&hl=tk',
    'to': 'https://www.google.to/search?q={}&num={}',
    'tn': 'https://www.google.tn/search?q={}&num={}',
    'tr': 'https://www.google.com.tr/search?q={}&num={}&hl=tr',
    'tt': 'https://www.google.tt/search?q={}&num={}',
    'tw': 'https://www.google.com.tw/search?q={}&num={}&hl=zh-TW',
    'tz': 'https://www.google.co.tz/search?q={}&num={}',
    'ua': 'https://www.google.com.ua/search?q={}&num={}&hl=uk',
    'ug': 'https://www.google.co.ug/search?q={}&num={}',
    'uk': 'https://www.google.co.uk/search?q={}&num={}&hl=en',
    'us': 'https://www.www.google.com/search?q={}&num={}&hl=en',
    'uy': 'https://www.google.com.uy/search?q={}&num={}&hl=es-419',
    'uz': 'https://www.google.co.uz/search?q={}&num={}&hl=uz',
    'vc': 'https://www.google.com.vc/search?q={}&num={}',
    've': 'https://www.google.co.ve/search?q={}&num={}&hl=es-419',
    'vg': 'https://www.google.vg/search?q={}&num={}',
    'vi': 'https://www.google.co.vi/search?q={}&num={}&hl=en',
    'vn': 'https://www.google.com.vn/search?q={}&num={}&hl=vi',
    'vu': 'https://www.google.vu/search?q={}&num={}',
    'ws': 'https://www.google.ws/search?q={}&num={}',
    'za': 'https://www.google.co.za/search?q={}&num={}',
    'zm': 'https://www.google.co.zm/search?q={}&num={}',
    'zw': 'https://www.google.co.zw/search?q={}&num={}',
}